==> aws-android-sdk-sqs-2.2.21-sources.jar: com/amazonaws/services/sqs/model/transform/DeleteMessageBatchResultStaxUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.sqs.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import org.xmlpull.v1.XmlPullParser;

import com.amazonaws.services.sqs.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * StAX unmarshaller for response DeleteMessageBatchResult
 */
public class DeleteMessageBatchResultStaxUnmarshaller implements
        Unmarshaller<DeleteMessageBatchResult, StaxUnmarshallerContext> {

    public DeleteMessageBatchResult unmarshall(StaxUnmarshallerContext context) throws Exception {
        DeleteMessageBatchResult deleteMessageBatchResult = new DeleteMessageBatchResult();

        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument())
            targetDepth += 2;

        while (true) {
            int xmlEvent = context.nextEvent();
            if (xmlEvent == XmlPullParser.END_DOCUMENT)
                break;

            if (xmlEvent == XmlPullParser.START_TAG) {
                if (context.testExpression("DeleteMessageBatchResultEntry", targetDepth)) {
                    deleteMessageBatchResult.getSuccessful().add(
                            DeleteMessageBatchResultEntryStaxUnmarshaller.getInstance().unmarshall(
                                    context));
                    continue;
                }
                if (context.testExpression("BatchResultErrorEntry", targetDepth)) {
                    deleteMessageBatchResult.getFailed()
                            .add(BatchResultErrorEntryStaxUnmarshaller.getInstance().unmarshall(
                                    context));
                    continue;
                }
            } else if (xmlEvent == XmlPullParser.END_TAG) {
                if (context.getCurrentDepth() < originalDepth) {
                    break;
                }
            }
        }
        return deleteMessageBatchResult;
    }

    private static DeleteMessageBatchResultStaxUnmarshaller instance;

    public static DeleteMessageBatchResultStaxUnmarshaller getInstance() {
        if (instance == null)
            instance = new DeleteMessageBatchResultStaxUnmarshaller();
        return instance;
    }
}

==> aws-android-sdk-sqs-2.3.1-sources.jar: com/amazonaws/services/sqs/model/transform/DeleteMessageBatchResultStaxUnmarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.sqs.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import org.xmlpull.v1.XmlPullParser;

import com.amazonaws.services.sqs.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * StAX unmarshaller for response DeleteMessageBatchResult
 */
public class DeleteMessageBatchResultStaxUnmarshaller implements
        Unmarshaller<DeleteMessageBatchResult, StaxUnmarshallerContext> {

    public DeleteMessageBatchResult unmarshall(StaxUnmarshallerContext context) throws Exception {
        DeleteMessageBatchResult deleteMessageBatchResult = new DeleteMessageBatchResult();

        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument())
            targetDepth += 2;

        while (true) {
            int xmlEvent = context.nextEvent();
            if (xmlEvent == XmlPullParser.END_DOCUMENT)
                break;

            if (xmlEvent == XmlPullParser.START_TAG) {
                if (context.testExpression("DeleteMessageBatchResultEntry", targetDepth)) {
                    deleteMessageBatchResult
                            .withSuccessful(DeleteMessageBatchResultEntryStaxUnmarshaller
                                    .getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("BatchResultErrorEntry", targetDepth)) {
                    deleteMessageBatchResult.withFailed(BatchResultErrorEntryStaxUnmarshaller
                            .getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent == XmlPullParser.END_TAG) {
                if (context.getCurrentDepth() < originalDepth) {
                    break;
                }
            }
        }
        return deleteMessageBatchResult;
    }

    private static DeleteMessageBatchResultStaxUnmarshaller instance;

    public static DeleteMessageBatchResultStaxUnmarshaller getInstance() {
        if (instance == null)
            instance = new DeleteMessageBatchResultStaxUnmarshaller();
        return instance;
    }
}
